=encoding utf8

=head1 NAME

Locale::CLDR::Locales::Nl::Any::Sr - Package for language Dutch

=cut

package Locale::CLDR::Locales::Nl::Any::Sr;
# This file auto generated from Data\common\main\nl_SR.xml
#	on Fri  3 Nov  7:08:28 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.3');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Nl::Any');
has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'SRD' => {
			symbol => '$',
		},
	} },
);


has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		'Suriname' => {
			short => {
				'standard' => q#SRT#,
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
